@@ -35,8 +35,9 @@
 #include <gtk/gtkwindow.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkimage.h>
-
-#include <libgnome/gnome-i18n.h>
+#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkwindow.h>
+#include <glib/gi18n.h>
 #include <libgnome/gnome-url.h>
 
 #include <libedataserver/e-xml-utils.h>
@@ -62,6 +63,7 @@ struct _e_error {
 	char *primary;
 	char *secondary;
 	char *help_uri;
+	gboolean scroll;
 	struct _e_error_button *buttons;
 };
 
@@ -81,10 +83,10 @@ static struct _e_error_button default_ok_button = {
 };
 
 static struct _e_error default_errors[] = {
-	{ GTK_DIALOG_MODAL, "error", 3, GTK_RESPONSE_OK, N_("Evolution Error"), "{0}", "{1}", NULL, &default_ok_button },
-	{ GTK_DIALOG_MODAL, "error-primary", 3, GTK_RESPONSE_OK, N_("Evolution Error"), "{0}", NULL, NULL, &default_ok_button },
-	{ GTK_DIALOG_MODAL, "warning", 1, GTK_RESPONSE_OK, N_("Evolution Warning"), "{0}", "{1}", NULL, &default_ok_button },
-	{ GTK_DIALOG_MODAL, "warning-primary", 1, GTK_RESPONSE_OK, N_("Evolution Warning"), "{0}", NULL, NULL, &default_ok_button },
+	{ GTK_DIALOG_MODAL, "error", 3, GTK_RESPONSE_OK, N_("Evolution Error"), "{0}", "{1}", NULL, FALSE, &default_ok_button },
+	{ GTK_DIALOG_MODAL, "error-primary", 3, GTK_RESPONSE_OK, N_("Evolution Error"), "{0}", NULL, NULL, FALSE, &default_ok_button },
+	{ GTK_DIALOG_MODAL, "warning", 1, GTK_RESPONSE_OK, N_("Evolution Warning"), "{0}", "{1}", NULL, FALSE, &default_ok_button },
+	{ GTK_DIALOG_MODAL, "warning-primary", 1, GTK_RESPONSE_OK, N_("Evolution Warning"), "{0}", NULL, NULL, FALSE, &default_ok_button },
 };
 
 /* ********************************************************************** */
@@ -176,8 +178,8 @@ ee_load(const char *path)
 
 	root = xmlDocGetRootElement(doc);
 	if (root == NULL
-	    || strcmp(root->name, "error-list") != 0
-	    || (tmp = xmlGetProp(root, "domain")) == NULL) {
+	    || strcmp((char *)root->name, "error-list") != 0
+	    || (tmp = (char *)xmlGetProp(root, (const unsigned char *)"domain")) == NULL) {
 		g_warning("Error file '%s' invalid format", path);
 		xmlFreeDoc(doc);
 		return;
@@ -192,12 +194,12 @@ ee_load(const char *path)
 		table->errors = g_hash_table_new(g_str_hash, g_str_equal);
 		g_hash_table_insert(error_table, table->domain, table);
 
-		tmp2 = xmlGetProp(root, "translation-domain");
+		tmp2 = (char *)xmlGetProp(root, (const unsigned char *)"translation-domain");
 		if (tmp2) {
 			table->translation_domain = g_strdup(tmp2);
 			xmlFree(tmp2);
 
-			tmp2 = xmlGetProp(root, "translation-localedir");
+			tmp2 = (char *)xmlGetProp(root, (const unsigned char *)"translation-localedir");
 			if (tmp2) {
 				bindtextdomain(table->translation_domain, tmp2);
 				xmlFree(tmp2);
@@ -208,71 +210,80 @@ ee_load(const char *path)
 	xmlFree(tmp);
 
 	for (error = root->children;error;error = error->next) {
-		if (!strcmp(error->name, "error")) {
-			tmp = xmlGetProp(error, "id");
+		if (!strcmp((char *)error->name, "error")) {
+			tmp = (char *)xmlGetProp(error, (const unsigned char *)"id");
 			if (tmp == NULL)
 				continue;
 
 			e = g_malloc0(sizeof(*e));
 			e->id = g_strdup(tmp);
+			e->scroll = FALSE;
+
 			xmlFree(tmp);
 			lastbutton = (struct _e_error_button *)&e->buttons;
 
-			tmp = xmlGetProp(error, "modal");
+			tmp = (char *)xmlGetProp(error, (const unsigned char *)"modal");
 			if (tmp) {
 				if (!strcmp(tmp, "true"))
 					e->flags |= GTK_DIALOG_MODAL;
 				xmlFree(tmp);
 			}
 
-			tmp = xmlGetProp(error, "type");
+			tmp = (char *)xmlGetProp(error, (const unsigned char *)"type");
 			e->type = map_type(tmp);
 			if (tmp)
 				xmlFree(tmp);
 
-			tmp = xmlGetProp(error, "default");
+			tmp = (char *)xmlGetProp(error, (const unsigned char *)"default");
 			if (tmp) {
 				e->default_response = map_response(tmp);
 				xmlFree(tmp);
 			}
+			
+			tmp = (char *)xmlGetProp(error, (const unsigned char *)"scroll");
+			if (tmp) {
+				if (!strcmp(tmp, "yes"))
+					e->scroll = TRUE;
+				xmlFree(tmp);
+			}
 
 			for (scan = error->children;scan;scan=scan->next) {
-				if (!strcmp(scan->name, "primary")) {
-					if ((tmp = xmlNodeGetContent(scan))) {
+				if (!strcmp((char *)scan->name, "primary")) {
+					if ((tmp = (char *)xmlNodeGetContent(scan))) {
 						e->primary = g_strdup(dgettext(table->translation_domain, tmp));
 						xmlFree(tmp);
 					}
-				} else if (!strcmp(scan->name, "secondary")) {
-					if ((tmp = xmlNodeGetContent(scan))) {
+				} else if (!strcmp((char *)scan->name, "secondary")) {
+					if ((tmp = (char *)xmlNodeGetContent(scan))) {
 						e->secondary = g_strdup(dgettext(table->translation_domain, tmp));
 						xmlFree(tmp);
 					}
-				} else if (!strcmp(scan->name, "title")) {
-					if ((tmp = xmlNodeGetContent(scan))) {
+				} else if (!strcmp((char *)scan->name, "title")) {
+					if ((tmp = (char *)xmlNodeGetContent(scan))) {
 						e->title = g_strdup(dgettext(table->translation_domain, tmp));
 						xmlFree(tmp);
 					}
-				} else if (!strcmp(scan->name, "help")) {
-					tmp = xmlGetProp(scan, "uri");
+				} else if (!strcmp((char *)scan->name, "help")) {
+					tmp = (char *)xmlGetProp(scan, (const unsigned char *)"uri");
 					if (tmp) {
 						e->help_uri = g_strdup(tmp);
 						xmlFree(tmp);
 					}
-				} else if (!strcmp(scan->name, "button")) {
+				} else if (!strcmp((char *)scan->name, "button")) {
 					struct _e_error_button *b;
 
 					b = g_malloc0(sizeof(*b));
-					tmp = xmlGetProp(scan, "stock");
+					tmp = (char *)xmlGetProp(scan, (const unsigned char *)"stock");
 					if (tmp) {
 						b->stock = g_strdup(tmp);
 						xmlFree(tmp);
 					}
-					tmp = xmlGetProp(scan, "label");
+					tmp = (char *)xmlGetProp(scan, (const unsigned char *)"label");
 					if (tmp) {
 						b->label = g_strdup(dgettext(table->translation_domain, tmp));
 						xmlFree(tmp);
 					}
-					tmp = xmlGetProp(scan, "response");
+					tmp = (char *)xmlGetProp(scan, (const unsigned char *)"response");
 					if (tmp) {
 						b->response = map_response(tmp);
 						xmlFree(tmp);
@@ -406,11 +417,12 @@ e_error_newv(GtkWindow *parent, const char *tag, const char *arg0, va_list ap)
 	struct _e_error_table *table;
 	struct _e_error *e;
 	struct _e_error_button *b;
-	GtkWidget *hbox, *w;
+	GtkWidget *hbox, *w, *scroll=NULL;
 	char *tmp, *domain, *id;
 	GString *out;
 	GPtrArray *args;
 	GtkDialog *dialog;
+	gchar *str;
 
 	if (error_table == NULL)
 		ee_load_tables();
@@ -439,7 +451,9 @@ e_error_newv(GtkWindow *parent, const char *tag, const char *arg0, va_list ap)
 	     || (table = g_hash_table_lookup(error_table, domain)) == NULL
 	     || (e = g_hash_table_lookup(table->errors, id)) == NULL) {
 		/* setup a dummy error */
-		tmp = g_strdup_printf(_("<span weight=\"bold\">Internal error, unknown error '%s' requested</span>"), tag);
+		str = g_strdup_printf(_("Internal error, unknown error '%s' requested"), tag);
+		tmp = g_strdup_printf("<span weight=\"bold\">%s</span>", str);
+		g_free(str);
 		w = gtk_label_new(NULL);
 		gtk_label_set_selectable((GtkLabel *)w, TRUE);
 		gtk_label_set_line_wrap((GtkLabel *)w, TRUE);
@@ -521,12 +535,22 @@ e_error_newv(GtkWindow *parent, const char *tag, const char *arg0, va_list ap)
 
 	g_ptr_array_free(args, TRUE);
 
+	if (e->scroll) {
+		scroll = gtk_scrolled_window_new (NULL, NULL);
+		gtk_scrolled_window_set_policy ((GtkScrolledWindow *)scroll, GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	}
 	w = gtk_label_new(NULL);
 	gtk_label_set_selectable((GtkLabel *)w, TRUE);
 	gtk_label_set_line_wrap((GtkLabel *)w, TRUE);
 	gtk_label_set_markup((GtkLabel *)w, out->str);
 	g_string_free(out, TRUE);
-	gtk_box_pack_start((GtkBox *)hbox, w, FALSE, FALSE, 0);
+	if (e->scroll) {
+		gtk_scrolled_window_add_with_viewport ((GtkScrolledWindow *)scroll, w);
+		gtk_box_pack_start((GtkBox *)hbox, scroll, FALSE, FALSE, 0);
+		gtk_window_set_default_size ((GtkWindow *)dialog, 360, 180);
+	} else 
+		gtk_box_pack_start((GtkBox *)hbox, w, FALSE, FALSE, 0);
+		
 	gtk_widget_show_all(hbox);
 
 	gtk_box_pack_start((GtkBox *)dialog->vbox, hbox, TRUE, TRUE, 0);
