@@ -34,8 +34,7 @@ static void e_text_event_processor_emacs_like_init		(ETextEventProcessorEmacsLik
 static void e_text_event_processor_emacs_like_class_init	(ETextEventProcessorEmacsLikeClass	 *klass);
 static gint e_text_event_processor_emacs_like_event (ETextEventProcessor *tep, ETextEventProcessorEvent *event);
 
-#define PARENT_TYPE E_TEXT_EVENT_PROCESSOR_TYPE
-static ETextEventProcessorClass *parent_class = NULL;
+G_DEFINE_TYPE (ETextEventProcessorEmacsLike, e_text_event_processor_emacs_like, E_TEXT_EVENT_PROCESSOR_TYPE)
 
 /* The arguments we take */
 enum {
@@ -103,13 +102,6 @@ static const ETextEventProcessorCommand alt_keys[26] =
 
 };
 
-E_MAKE_TYPE (e_text_event_processor_emacs_like,
-	     "ETextEventProcessorEmacsLike",
-	     ETextEventProcessorEmacsLike,
-	     e_text_event_processor_emacs_like_class_init,
-	     e_text_event_processor_emacs_like_init,
-	     PARENT_TYPE)
-
 static void
 e_text_event_processor_emacs_like_class_init (ETextEventProcessorEmacsLikeClass *klass)
 {
@@ -117,8 +109,6 @@ e_text_event_processor_emacs_like_class_init (ETextEventProcessorEmacsLikeClass
 
   processor_class = (ETextEventProcessorClass*) klass;
 
-  parent_class = g_type_class_ref (PARENT_TYPE);
-
   processor_class->event = e_text_event_processor_emacs_like_event;
 }
 
@@ -270,6 +260,22 @@ e_text_event_processor_emacs_like_event (ETextEventProcessor *tep, ETextEventPro
 				/* gtk_toggle_insert(text) -- IMPLEMENT -- FIXME */
 				}
 				break;
+			case GDK_F16:
+				command.action = E_TEP_COPY;
+				command.position = E_TEP_SELECTION;
+				break;
+			case GDK_F18:
+				command.action = E_TEP_PASTE;
+				command.position = E_TEP_SELECTION;
+				break;
+			case GDK_F20:
+				command.action = E_TEP_COPY;
+				command.position = E_TEP_SELECTION;
+				g_signal_emit_by_name (tep, "command", &command);
+				
+				command.action = E_TEP_DELETE;
+				command.position = E_TEP_SELECTION;
+				break;
 			case GDK_Delete:
 			case GDK_KP_Delete:
 				if (key.state & GDK_CONTROL_MASK){
