@@ -28,7 +28,7 @@
 
 #include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include "camel/camel-url.h"
 #include "em-vfolder-context.h"
@@ -57,9 +57,9 @@ static void em_vfolder_rule_finalise(GObject *obj);
 /* DO NOT internationalise these strings */
 static const char *with_names[] = {
 	"specific",
-	"local",
+	"local_remote_active",
 	"remote_active",
-	"local_remote_active"
+	"local"
 };
 
 static FilterRuleClass *parent_class = NULL;
@@ -256,17 +256,16 @@ xml_encode(FilterRule *fr)
 	EMVFolderRule *vr =(EMVFolderRule *)fr;
 	xmlNodePtr node, set, work;
 	GList *l;
-	
         node = FILTER_RULE_CLASS(parent_class)->xml_encode(fr);
 	g_assert(node != NULL);
 	g_assert(vr->with >= 0 && vr->with < sizeof(with_names)/sizeof(with_names[0]));
-	set = xmlNewNode(NULL, "sources");
+	set = xmlNewNode(NULL, (const unsigned char *)"sources");
 	xmlAddChild(node, set);
-	xmlSetProp(set, "with", with_names[vr->with]);
+	xmlSetProp(set, (const unsigned char *)"with", (unsigned char *)with_names[vr->with]);
 	l = vr->sources;
 	while (l) {
-		work = xmlNewNode(NULL, "folder");
-		xmlSetProp(work, "uri", l->data);
+		work = xmlNewNode(NULL, (const unsigned char *)"folder");
+		xmlSetProp(work, (const unsigned char *)"uri", (unsigned char *)l->data);
 		xmlAddChild(set, work);
 		l = l->next;
 	}
@@ -310,16 +309,16 @@ xml_decode(FilterRule *fr, xmlNodePtr node, struct _RuleContext *f)
 
 	set = node->children;
 	while (set) {
-		if (!strcmp(set->name, "sources")) {
-			tmp = xmlGetProp(set, "with");
+		if (!strcmp((char *)set->name, "sources")) {
+			tmp = (char *)xmlGetProp(set, (const unsigned char *)"with");
 			if (tmp) {
 				set_with(vr, tmp);
 				xmlFree(tmp);
 			}
 			work = set->children;
 			while (work) {
-				if (!strcmp(work->name, "folder")) {
-					tmp = xmlGetProp(work, "uri");
+				if (!strcmp((char *)work->name, "folder")) {
+					tmp = (char *)xmlGetProp(work, (const unsigned char *)"uri");
 					if (tmp) {
 						vr->sources = g_list_append(vr->sources, g_strdup(tmp));
 						xmlFree(tmp);
@@ -373,6 +372,7 @@ struct _source_data {
 	const char *current;
 	GtkListStore *model;
 	GtkTreeView *list;
+	GtkWidget *source_selector;
 	GtkButton *buttons[BUTTON_LAST];
 };
 
@@ -413,11 +413,25 @@ select_source(GtkWidget *list, struct _source_data *data)
 static void
 select_source_with_changed(GtkWidget *widget, struct _source_data *data)
 {
-	em_vfolder_rule_with_t with;
+	em_vfolder_rule_with_t with = 0;
+	GSList *group = NULL;
+	gint i = 0;	
 
-	with = gtk_option_menu_get_history((GtkOptionMenu *)widget);
-	if (with < EM_VFOLDER_RULE_WITH_SPECIFIC || with > EM_VFOLDER_RULE_WITH_LOCAL_REMOTE_ACTIVE)
+	if ( !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)) )
+		return;
+
+	group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
+
+	for (i=0; i< g_slist_length(group); i++) {
+		if ( g_slist_nth_data (group, with = i) == widget ) 
+			break;
+	}
+
+	if ( with < EM_VFOLDER_RULE_WITH_SPECIFIC || with > EM_VFOLDER_RULE_WITH_LOCAL )
 		with = 0;
+
+	gtk_widget_set_sensitive (data->source_selector, !with );
+
 	data->vr->with = with;
 }
 
@@ -598,7 +612,7 @@ get_widget(FilterRule *fr, RuleContext *rc)
 	EMVFolderRule *vr =(EMVFolderRule *)fr;
 	GtkWidget *widget, *frame, *list;
 	struct _source_data *data;
-	GtkOptionMenu *omenu;
+	GtkRadioButton *rb;
 	const char *source;
 	GtkTreeIter iter;
 	GladeXML *gui;
@@ -641,9 +655,23 @@ get_widget(FilterRule *fr, RuleContext *rc)
 	
 	g_signal_connect(data->list, "cursor-changed", G_CALLBACK(select_source), data);
 	
-	omenu =(GtkOptionMenu *)glade_xml_get_widget(gui, "source_option");
-	gtk_option_menu_set_history(omenu, vr->with);
-	g_signal_connect(omenu, "changed", G_CALLBACK(select_source_with_changed), data);
+	rb = (GtkRadioButton *)glade_xml_get_widget (gui, "local_rb");
+	g_signal_connect (GTK_WIDGET(rb), "toggled", G_CALLBACK(select_source_with_changed), data);
+
+	rb = (GtkRadioButton *)glade_xml_get_widget (gui, "remote_rb");
+	g_signal_connect (GTK_WIDGET(rb), "toggled", G_CALLBACK(select_source_with_changed), data);
+
+	rb = (GtkRadioButton *)glade_xml_get_widget (gui, "local_and_remote_rb");
+	g_signal_connect (GTK_WIDGET(rb), "toggled", G_CALLBACK(select_source_with_changed), data);
+
+	rb = (GtkRadioButton *)glade_xml_get_widget (gui, "specific_rb");
+	g_signal_connect (GTK_WIDGET(rb), "toggled", G_CALLBACK(select_source_with_changed), data);
+
+	data->source_selector = (GtkWidget *)glade_xml_get_widget (gui, "source_selector");
+
+	rb = g_slist_nth_data(gtk_radio_button_get_group (rb), vr->with);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rb), TRUE);
+	gtk_signal_emit_by_name (GTK_OBJECT (rb), "toggled");
 	
 	set_sensitive(data);
 		
