@@ -123,7 +123,7 @@ int mail_save_messages (CamelFolder *folder, GPtrArray *uids, const char *path,
 
 int mail_save_part (CamelMimePart *part, const char *path,
 		    void (*done)(CamelMimePart *part, char *path, int saved, void *data),
-		    void *data);
+		    void *data, gboolean readonly);
 
 /* yeah so this is messy, but it does a lot, maybe i can consolidate all user_data's to be the one */
 void mail_send_queue (CamelFolder *queue, const char *destination,
@@ -155,6 +155,7 @@ void mail_prep_offline(const char *uri, CamelOperation *cancel,
 int mail_store_set_offline(CamelStore *store, gboolean offline,
 			   void (*done)(CamelStore *, void *data),
 			   void *data);
+int mail_store_prepare_offline (CamelStore *store);
 
 /* filter driver execute shell command async callback */
 void mail_execute_shell_command (CamelFilterDriver *driver, int argc, char **argv, void *data);
