@@ -37,13 +37,14 @@
 #include <gtk/gtkoptionmenu.h>
 #include <gtk/gtksignal.h>
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include <bonobo/bonobo-ui-node.h>
 #include <bonobo/bonobo-ui-util.h>
 
 typedef enum {
 	E_CHARSET_UNKNOWN,
+	E_CHARSET_ARABIC,
 	E_CHARSET_BALTIC,
 	E_CHARSET_CENTRAL_EUROPEAN,
 	E_CHARSET_CHINESE,
@@ -61,6 +62,7 @@ typedef enum {
 
 static const char *classnames[] = {
 	N_("Unknown"),
+	N_("Arabic"),
 	N_("Baltic"),
 	N_("Central European"),
 	N_("Chinese"),
@@ -86,7 +88,9 @@ typedef struct {
  * not a lot of point in using, say, ISO-8859-3, if anything that can
  * read that can read UTF8 too.
  */
+/* To Translators: Character set "Logical Hebrew" */
 static ECharset charsets[] = {
+	{ "ISO-8859-6", E_CHARSET_ARABIC, NULL },
 	{ "ISO-8859-13", E_CHARSET_BALTIC, NULL },
 	{ "ISO-8859-4", E_CHARSET_BALTIC, NULL },
 	{ "ISO-8859-2", E_CHARSET_CENTRAL_EUROPEAN, NULL },
